// 运行时配置
import RightContent from '@/components/RightContent';
import type { RequestConfig, RunTimeLayoutConfig } from '@umijs/max';
import React from 'react';
import logo from './assets/logo.jpg';

/**
 * 获取页面初始数据
 * @returns
 */
export async function getInitialState(): Promise<{
  name: string; // 用户名称
  avatar: string; // 用户头像
  menu: object[]; // 菜单
}> {
  return {
    name: 'zhst',
    avatar: '',
    menu: [],
  };
}

const menuExtraRender = () => {
  return (
    <p style={{ margin: '16px 0', textAlign: 'center', fontSize: '24px' }}>
      AI 算法仓平台
    </p>
  );
};

// TODO: 通过 initialState 获取用户信息和路由菜单渲染 menu
// @ts-ignore
export const layout: RunTimeLayoutConfig = (props) => {
  const { initialState } = props;
  const getMenu = () => {
    return [
      {
        path: '/home',
        name: '首页',
      },
      {
        path: '/table',
        name: '表单',
      },
      {
        path: '/access',
        name: '权限测试',
      },
      {
        path: '/performance',
        name: '性能测试',
      },
    ];
  };

  return {
    rightContentRender: false,
    disableContentMargin: false,
    childrenRender: (dom) => {
      console.log('_props', props);
      return (
        <div>
          <div
            style={{
              height: '54px',
              lineHeight: '54px',
              borderBottom: '1px solid rgba(0,0,0,0.06)',
            }}
          >
            <RightContent />
          </div>
          {dom}
        </div>
      );
    },
    waterMarkProps: {
      content: initialState?.name,
    },
    menuExtraRender,
    onPageChange: () => {
      console.log('页面跳转');
      // TODO: 如果没有登录，重定向到 login
      // if (!initialState?.currentUser && location.pathname !== loginPath) {
      //   history.push(loginPath);
      // }
    },
    layout: 'side',
    // 自定义 404 页面
    logo,
    title: () => null,
    iconfontUrl: '',
    logout: () => {},
    // rightContentRender
    menu: {
      request: getMenu,
    },
  };
};

export const request: RequestConfig = {
  timeout: 1000,
  // other axios options you want
  errorConfig: {
    // @ts-ignore
    errorHandler(error: any, opts: any) {
      console.log('first', error, opts);
      // if (opts?.skipErrorHandler) throw error
      // try {
      //   const { res } = ctx;
      //   const d = await res.text();

      //   if (res.status === 401 && store.user.isLogin) {
      //     store.user.resetLoginState();
      //     message.warning('登录过期，请重新登录!');
      //     return;
      //   }
      //   const isEmptyRes = d === '' || d.replace(/\s/g,"")=== 'tokenisinvalid'; //有些后端接口成功会返回空 做下兼容
      //   const body = !isEmptyRes ? JSON.parse(d || '{}') : d;
      //   const sessionCode = sessionStorage.getItem('zhst_errcode') || '{}'
      //   const ERROR_CODE = JSON.parse(sessionCode);

      //   if (Number(res.status) === 200) {
      //     ctx.res = body;
      //   } else {
      //     // 先判断Grpc-Metadata-Errorx-Message
      //     let errMsg = ERROR_CODE[body.code]?.value || body.message || '您的网络发生异常，无法连接服务器'
      //     toast && message.error(errMsg || body);
      //     ctx.res = {
      //       code: body.code,
      //       message: errMsg
      //     };
      //   }

      // } catch (error) {
      //   if (get(error, 'type') !== 'CustomError') {
      //     toast && message.error('您的网络发生异常，无法连接服务器');
      //   }
      //   throw error;
      // }
    },
    // @ts-ignore
    errorThrower(res) {
      console.log('res', res);
    },
  },
  // 请求
  requestInterceptors: [
    // 一个二元组，第一个元素是 request 拦截器，第二个元素是错误处理
    [
      (url, options) => {
        console.log('options', options);
        return {
          url,
          options: {
            ...options,
            headers: {
              authorization: 'test',
              // ...(refererSuffix ? { zhst_referer: `${baseUrl}${refererSuffix}` } : {}),
            },
          },
        };
      },
      (error) => {
        return Promise.reject(error);
      },
    ],
  ],
  // 返回
  responseInterceptors: [
    // 一个二元组，第一个元素是 request 拦截器，第二个元素是错误处理
    [
      (response) => {
        if (response.status === 200) {
          throw Error(JSON.stringify(response.data));
        }
        return response;
      },
      (error) => {
        return Promise.reject(error);
      },
    ],
  ],
};
